@@ -40,24 +40,24 @@ from robotcode.core.utils.inspect import ensure_coroutine, iter_methods
 from robotcode.core.utils.logging import LoggingDescriptor
 
 __all__ = [
+    "GenericJsonRPCProtocolPart",
+    "InvalidProtocolVersionError",
+    "JsonRPCError",
+    "JsonRPCErrorException",
+    "JsonRPCErrorObject",
     "JsonRPCErrors",
+    "JsonRPCException",
     "JsonRPCMessage",
     "JsonRPCNotification",
+    "JsonRPCParseError",
+    "JsonRPCProtocol",
+    "JsonRPCProtocolPart",
     "JsonRPCRequest",
     "JsonRPCResponse",
-    "JsonRPCError",
-    "JsonRPCErrorObject",
-    "JsonRPCProtocol",
-    "JsonRPCException",
-    "JsonRPCParseError",
-    "InvalidProtocolVersionError",
-    "rpc_method",
-    "RpcRegistry",
-    "JsonRPCProtocolPart",
     "ProtocolPartDescriptor",
-    "GenericJsonRPCProtocolPart",
+    "RpcRegistry",
     "TProtocol",
-    "JsonRPCErrorException",
+    "rpc_method",
 ]
 
 _T = TypeVar("_T")
@@ -196,7 +196,7 @@ def rpc_method(
         if isinstance(func, classmethod):
             f = func.__func__  # type: ignore
         elif isinstance(func, staticmethod):
-            f = func.__func__  # type: ignore
+            f = func.__func__
         else:
             f = func
 
@@ -278,8 +278,7 @@ class RpcRegistry:
                     iter_methods(
                         obj,
                         lambda m2: isinstance(m2, RpcMethod)
-                        or inspect.ismethod(m2)
-                        and isinstance(m2.__func__, RpcMethod),
+                        or (inspect.ismethod(m2) and isinstance(m2.__func__, RpcMethod)),
                     ),
                 )
             }
@@ -501,7 +500,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             raise
         except BaseException as e:
             self.__logger.exception(e)
-            self.send_error(JsonRPCErrors.PARSE_ERROR, f"{type(e).__name__}: {e}")
+            self.send_error(JsonRPCErrors.PARSE_ERROR, f"{e}")
 
     def _handle_messages(self, iterator: Iterator[JsonRPCMessage]) -> None:
         for m in iterator:
@@ -551,11 +550,14 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         if self.write_transport is not None:
             msg = header + body
 
-            self._data_logger.trace(lambda: f"JSON send: {msg.decode()!r}")
+            self._do_trace_message(message, msg)
 
             if self._loop:
                 self._loop.call_soon_threadsafe(self.write_transport.write, msg)
 
+    def _do_trace_message(self, message: JsonRPCMessage, msg: bytes) -> None:
+        self._data_logger.trace(lambda: f"JSON send: {msg.decode()!r}")
+
     @__logger.call
     def send_request(
         self,
@@ -784,6 +786,9 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                     ex = t.exception()
                     if ex is not None:
                         self.__logger.exception(ex, exc_info=ex)
+                        if isinstance(ex, JsonRPCErrorException):
+                            raise ex
+
                         raise JsonRPCErrorException(
                             JsonRPCErrors.INTERNAL_ERROR,
                             f"{type(ex).__name__}: {ex}",
@@ -802,7 +807,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         except JsonRPCErrorException as e:
             self.send_error(
                 e.code,
-                e.message or f"{type(e).__name__}: {e}",
+                e.message or f"{e}",
                 id=message.id,
                 data=e.data,
             )
@@ -810,7 +815,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             self.__logger.exception(e)
             self.send_error(
                 JsonRPCErrors.INTERNAL_ERROR,
-                f"{type(e).__name__}: {e}",
+                f"{e}",
                 id=message.id,
             )
 
