@@ -6,6 +6,7 @@ import threading
 from concurrent.futures import ThreadPoolExecutor
 from types import TracebackType
 from typing import (
+    Any,
     BinaryIO,
     Callable,
     Coroutine,
@@ -44,7 +45,7 @@ class StdOutTransportAdapter(asyncio.Transport):
         self.rfile.close()
         self.wfile.close()
 
-    def write(self, data: bytes) -> None:
+    def write(self, data: "bytes | bytearray | memoryview[Any]") -> None:
         self.wfile.write(data)
         self.wfile.flush()
 
@@ -85,7 +86,7 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
         elif self.mode == ServerMode.TCP:
             self.loop.run_until_complete(self.start_tcp(self.tcp_params.host, self.tcp_params.port))
         elif self.mode == ServerMode.PIPE:
-            self.start_pipe(self.pipe_name)
+            self.loop.run_until_complete(self.start_pipe(self.pipe_name))
         elif self.mode == ServerMode.PIPE_SERVER:
             self.loop.run_until_complete(self.start_pipe_server(self.pipe_name))
         elif self.mode == ServerMode.SOCKET:
@@ -94,7 +95,9 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
                 (
                     self.tcp_params.host
                     if isinstance(self.tcp_params.host, str)
-                    else self.tcp_params.host[0] if self.tcp_params.host else None
+                    else self.tcp_params.host[0]
+                    if self.tcp_params.host
+                    else None
                 ),
             )
         else:
@@ -174,7 +177,7 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
     def start_stdio(self) -> None:
         self.mode = ServerMode.STDIO
 
-        transport = StdOutTransportAdapter(sys.__stdin__.buffer, sys.__stdout__.buffer)
+        transport = StdOutTransportAdapter(sys.__stdin__.buffer, sys.__stdout__.buffer)  # type: ignore
 
         protocol = self.create_protocol()
 
@@ -212,7 +215,7 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
         self._run_func = self.loop.run_forever
 
     @_logger.call
-    def start_pipe(self, pipe_name: Optional[str]) -> None:
+    async def start_pipe(self, pipe_name: Optional[str]) -> None:
         from typing import TYPE_CHECKING
 
         if pipe_name is None:
@@ -227,17 +230,16 @@ class JsonRPCServer(Generic[TProtocol], abc.ABC):
                 if TYPE_CHECKING:
                     from asyncio.windows_events import ProactorEventLoop
 
-                self.loop.run_until_complete(
-                    cast("ProactorEventLoop", self.loop).create_pipe_connection(
-                        lambda: cast(
-                            "asyncio.StreamReaderProtocol",
-                            self.create_protocol(),
-                        ),
-                        pipe_name,
-                    )
+                await cast("ProactorEventLoop", self.loop).create_pipe_connection(
+                    lambda: cast(
+                        "asyncio.StreamReaderProtocol",
+                        self.create_protocol(),
+                    ),
+                    pipe_name,
                 )
+
             else:
-                self.loop.run_until_complete(self.loop.create_unix_connection(self.create_protocol, pipe_name))
+                await self.loop.create_unix_connection(self.create_protocol, pipe_name)
         except NotImplementedError as e:
             raise NotSupportedError("Pipe transport is not supported on this platform.") from e
 
